package xn.hxp.ui.common;

import android.os.Bundle;
import android.os.CountDownTimer;

import androidx.annotation.Nullable;
import androidx.viewbinding.ViewBinding;

import com.blankj.utilcode.util.ActivityUtils;
import com.blankj.utilcode.util.LogUtils;
import com.kongzue.dialogx.dialogs.PopTip;
import com.kongzue.dialogx.dialogs.WaitDialog;
import com.rc.core.ui.activity.RcBaseActivity;
import com.rc.httpcore.HttpClient;
import com.rc.httpcore.bean.ConfigBean;
import com.rc.httpcore.client.ApiRepository;

import xn.hxp.app.ChemicalApp;
import xn.hxp.comm.Constants;
import xn.hxp.ui.SplashActivity;

public abstract class BaseCountDownActivity<VB extends ViewBinding> extends RcBaseActivity<VB> {

    // 公共配置倒计时长
    private int backTime = 60;
    // 页面自定义倒计时长
    private int cTime = 0;
    private CountDownTimer countDownTimer;

    private void cdEnd() {
        // 下面逻辑是之前开发者的  很难理解为什么写
        if (Constants.INSTANCE.getVIEW_TYPE()) {
            cdFinish();
        } else {
            ActivityUtils.startActivity(SplashActivity.class);
            LogUtils.d(ActivityUtils.getActivityList());
        }
    }

    private void invokeTime(int cd) {
        if (!isDestroyed()) {
            cdTime(cd);
        }
    }

    /**
     * 当前页最大倒计时
     */
    protected void setCTime(int cd) {
        cTime = cd;
    }

    protected abstract void cdTime(int cd);

    protected void cdFinish() {
    }

    /**
     * 重置时间
     */
    private void reSetCdTime() {
        ConfigBean configBean = ChemicalApp.confs;
        if (null != configBean) {
            backTime = configBean.getBackTime();
            Constants.INSTANCE.setOFFTIME_TIME(configBean.getOffTime());
        }
    }

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        // 重置时间
        reSetCdTime();
        cTime = 0;
    }

    @Override
    protected void onResume() {
        super.onResume();
        openCD();
    }

    @Override
    protected void onPause() {
        super.onPause();
        stopCountDown();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        stopCountDown();
    }

    @Override
    public void onUserInteraction() {
        super.onUserInteraction();
        reSetCdTime();
    }

    private void openCD() {
        stopCountDown();
        countDownTimer = new CountDownTimer(1000, 1000) {
            @Override
            public void onTick(long millisUntilFinished) {

            }


            @Override
            public void onFinish() {
                if (!isFinishing() && !isDestroyed()) {
                    if (cTime > 0) {
                        cTime--;
                        if (cTime <= 0) {
                            cdEnd();
                        } else {
                            invokeTime(cTime);
                        }
                    } else {
                        backTime--;
                        if (backTime <= 0) {
                            cdEnd();
                        } else {
                            invokeTime(backTime);
                        }
                    }
                    countDownTimer.start();
                }
            }
        };
        countDownTimer.start();
    }

    protected void stopCountDown() {
        if (null != countDownTimer) {
            countDownTimer.cancel();
            countDownTimer = null;
        }
    }

    protected void callLogoutApi() {
        WaitDialog.show("退出中...");
        addDisposable(ApiRepository.INSTANCE.loginOut().subscribe(aBoolean -> {
            WaitDialog.dismiss();
            ChemicalApp.userData = null;
            ChemicalApp.subjectId = null;
            HttpClient.INSTANCE.setToken(null);
            ActivityUtils.startActivity(SplashActivity.class);
        }, throwable -> {
            WaitDialog.dismiss();
            PopTip.show(throwable.getMessage());
        }));
    }
}
