package xn.hxp.ui.warehousing

import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.view.LayoutInflater
import com.bumptech.glide.Glide
import com.bumptech.glide.load.engine.DiskCacheStrategy
import com.bumptech.glide.request.RequestOptions
import com.caysn.autoreplyprint.AutoReplyPrint
import xn.hxp.R
import xn.hxp.databinding.ActivityElectronicLedgerBinding
import xn.hxp.ui.SplashActivity
import xn.hxp.ui.common.BaseCountDownActivity
import xn.hxp.utils.BitmapUtils
import xn.hxp.utils.MediaPlayerHelper
import xn.hxp.utils.TimeUpdater
import xn.hxp.utils.UiManager
import xn.hxp.weidith.AirBottleDialog
import xn.hxp.weidith.CustomDialog
import com.blankj.utilcode.util.LogUtils
import com.rc.httpcore.HttpClient
import com.rc.httpcore.HttpConfig
import com.sun.jna.Pointer
import xn.hxp.app.ChemicalApp
import xn.hxp.utils.PrintTool

//标签管理
class ElectronicLedgerActivity : BaseCountDownActivity<ActivityElectronicLedgerBinding>() {

    private lateinit var timeUpdater: TimeUpdater
    override fun createViewBinding() =
        ActivityElectronicLedgerBinding.inflate(LayoutInflater.from(this))

    override fun initViews(savedInstanceState: Bundle?) {
        super.initViews(savedInstanceState)
        viewBinding.tvReturn.text = "返回${ChemicalApp.confs!!.backTime}s"
        viewBinding.tvOutLogin.setOnClickListener {
            callLogoutApi()
        }
        viewBinding.tvReturn.setOnClickListener {
            finish()
        }

        viewBinding.chemicalLabeling.setOnClickListener {
            //化学品标签
            UiManager.switcher(this, ChemicalLabelingActivity::class.java)
        }

        viewBinding.cylinderLabel.setOnClickListener {
            //气瓶标签
            var airBottleDialog = AirBottleDialog(this, object : AirBottleDialog.ILintDate {
                override fun onLintDate(cont: String) {
                    if (cont.isNotEmpty()) {
                        PrintTool.INSTANCE.print(cont)
                    }
                }
            })
            airBottleDialog.show()
        }
    }

    override fun initData() {
        super.initData()
        val handler = Handler(Looper.getMainLooper())
        timeUpdater = TimeUpdater(handler) { currentTime ->
            viewBinding.nowTime.text = "$currentTime"
        }
        // 启动定时更新
        timeUpdater.startUpdating()


        viewBinding.tvName.text = ChemicalApp.userData!!.userName
        val imageView = viewBinding.imageName
        // 使用 Glide 加载网络图片
        Glide.with(this)
            .load("${HttpConfig.API_BASE_IMG_URL}${ChemicalApp.userData!!.avatar}")
            .apply(RequestOptions.diskCacheStrategyOf(DiskCacheStrategy.AUTOMATIC))
            .into(imageView)

        // 使用 Glide 加载网络图片
        viewBinding.deptName.text = "${ChemicalApp.confs!!.deptName}-${ChemicalApp.confs!!.roomNum}"
        Glide.with(this)
            .load("${HttpConfig.API_BASE_IMG_URL}${ChemicalApp.confs!!.circularLogo}")
            .apply(RequestOptions.diskCacheStrategyOf(DiskCacheStrategy.AUTOMATIC))
            .into(viewBinding.image)
    }

    override fun onBackPressed() {
        super.onBackPressed()
        finish()
    }

    override fun cdTime(cd: Int) {
        viewBinding.tvReturn.text = "返回${cd}s"
    }

    override fun onDestroy() {
        super.onDestroy()
        try {
            timeUpdater.stopUpdating()
        } catch (e: Exception) {
        }
    }

    /**
     * 0  没有图标 1 绿色(成功)   2红色（失败）
     *   失败或者成功的弹框
     */
    private fun customDialogView(types: Int, msg: String) {
        if (!this.isFinishing && !this.isDestroyed) {
            val customDialog = CustomDialog(this, types, msg)
            customDialog.show()
        }
    }
}